==> KekikTaban-0.2.0.tar.gz: KekikTaban-0.2.0/README.md <==
# <img src="https://www.akashtrehan.com/assets/images/emoji/terminal.png" height="48" align="center"> KekikTaban

![Repo Boyutu](https://img.shields.io/github/repo-size/keyiflerolsun/KekikTaban) ![Views](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https://github.com/keyiflerolsun/KekikTaban&title=Profile%20Views) [![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/keyiflerolsun/KekikTaban)

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/KekikTaban)
![PyPI - Status](https://img.shields.io/pypi/status/KekikTaban)
![PyPI](https://img.shields.io/pypi/v/KekikTaban)
![PyPI - Downloads](https://img.shields.io/pypi/dm/KekikTaban)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/KekikTaban)
![PyPI - License](https://img.shields.io/pypi/l/KekikTaban)

**[@KekikAkademi](https://github.com/KekikAkademi)** *adına yazılmış Projelerin Terminal Tabanı ve Biraz Dahası*

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![ForTheBadge built-with-love](http://ForTheBadge.com/images/badges/built-with-love.svg)](https://GitHub.com/keyiflerolsun/)

## 🚀 Kurulum

```bash
# Yüklemek
pip install KekikTaban

# Güncellemek
pip install -U KekikTaban
```

## <img src="https://i.imgur.com/ETZ1ABF.png" height="24" align="center"> Kullanım

> ### **[KekikTaban](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/konsolTaban.py)**
```python
from KekikTaban import KekikTaban

taban = KekikTaban(
    baslik   = "@KekikAkademi Userbot",
    aciklama = "kekikUserbot Başlatıldı..",
    banner   = "kekikUserbot",
    girinti  = 1
)

taban.log_salla('a', 'b', 'c')
taban.log_salla('sol', 'orta', 'sag')
taban.log_salla('@keyiflerolsun', '.nekover py', 'Kekik | Kahve')


test = "abcdefghijklmnopqrstuvwxyz"

konsol = taban.konsol
konsol.print(f"{len(test)}", justify="center", style="blink bold red underline on white")

from rich.style import Style
tehlike = Style(color="red", blink=True, bold=True)
konsol.print(f"{len(test)}", justify="center", style=tehlike)

taban.log_salla(test, test, test)

try:
    bakalim()
except Exception as hata:
    taban.hata_salla(hata)
```

> ### **[slugify](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/ascii_decode.py)**
```python
from KekikTaban import slugify

print(slugify("Ömer Faruk Sancak"))

# » omer-faruk-sancak
```

> ### **[link_ayikla](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/link_islemleri.py)**
```python
from KekikTaban import link_ayikla

print(link_ayikla("Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent ornare nec turpis at mollis. Aenean iaculis metus libero, a rhoncus justo suscipit quis. Suspendisse sodales ante eros. Curabitur sagittis massa lacus, vel placerat turpis aliquet ac. Nulla porta cursus consequat. Etiam tristique vestibulum maximus. Vestibulum scelerisque vehicula ex, non feugiat eros placerat a. Cras eleifend cursus felis. Nullam pulvinar dictum purus, eu lobortis sapien posuere accumsan. Integer suscipit nisi diam, nec gravida eros malesuada a. Sed vestibulum sollicitudin ex ut volutpat. Phasellus non magna sed neque blandit vestibulum vitae nec ante. https://google.com Proin fringilla ligula nec metus sagittis venenatis."))

# ['https://google.com']
```

> ### **[youtube_link_mi](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/link_islemleri.py)**
```python
from KekikTaban import youtube_link_mi

print(youtube_link_mi("https://google.com"))

# False
```

> ### **[okunabilir_byte](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/okunabilir_byte.py)**
```python
from KekikTaban import okunabilir_byte

print(okunabilir_byte(132456498564))

# 123.36 GB
```

> ### **[zaman_donustur](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/zaman_donustur.py)**
```python
from KekikTaban import zaman_donustur

print(zaman_donustur(123456))

# 1 gün, 10 saat, 17 dakika, 36 saniye
```

> ### **[qr_ver](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/qr_ver.py)**
```python
from KekikTaban import qr_ver

print(qr_ver("keyiflerolsun"))

                         
#   █▀▀▀▀▀█ ▀▀▀▄▀ █▀▀▀▀▀█  
#   █ ███ █ ▀█ ██ █ ███ █  
#   █ ▀▀▀ █ ▄▄▄██ █ ▀▀▀ █  
#   ▀▀▀▀▀▀▀ ▀▄▀ █ ▀▀▀▀▀▀▀  
#   ▀▄█ ▄ ▀█▄▀▄    █▄▄▀ █  
#   ▀▀▄▄██▀█ ▄▄▀██ ▄▀▄▀▄█  
#     ▀  ▀▀▀███ ▄█▄ █ ▄▀▄  
#   █▀▀▀▀▀█ ▀ ▀▄▀▄  ▀▄▀▄▀  
#   █ ███ █  ▄█▄██▄ ▄▀▄    
#   █ ▀▀▀ █ ▀█▀▄██▀ █▄▀▀▀  
#   ▀▀▀▀▀▀▀ ▀ ▀▀▀   ▀▀  ▀  
```

> ### **[dict2json]**(https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/dict2json.py)
> ### **[dosya_indir]**(https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/dosya_indir.py)
> ### **[benim_hwid]**(https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/hwid_kontrol.py)
> ### **[hwid_kontrol]**(https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/hwid_kontrol.py)
> ### **[satir_ekle]**(https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/txt_fetis.py)
> ### **[satirlar_ekle]**(https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/txt_fetis.py)
> ### **[list2html]**(https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/list2html.py)

## 💸 Bağış Yap

**[☕️ Kahve Ismarla](https://KekikAkademi.org/Kahve)**

## 🌐 Telif Hakkı ve Lisans

* *Copyright (C) 2022 by* [keyiflerolsun](https://github.com/keyiflerolsun) ❤️️
* [GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007](https://github.com/keyiflerolsun/keyifUserBot/blob/master/LICENSE) *Koşullarına göre lisanslanmıştır..*

## ♻️ İletişim

*Benimle iletişime geçmek isterseniz, **Telegram**'dan mesaj göndermekten çekinmeyin;* [@keyiflerolsun](https://t.me/keyiflerolsun)

##

> **[@KekikAkademi](https://t.me/KekikAkademi)** *için yazılmıştır..*

==> KekikTaban-0.2.2.tar.gz: KekikTaban-0.2.2/README.md <==
# <img src="https://www.akashtrehan.com/assets/images/emoji/terminal.png" height="48" align="center"> KekikTaban

![Repo Boyutu](https://img.shields.io/github/repo-size/keyiflerolsun/KekikTaban) ![Views](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https://github.com/keyiflerolsun/KekikTaban&title=Profile%20Views) [![Gitpod ready-to-code](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/keyiflerolsun/KekikTaban)

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/KekikTaban)
![PyPI - Status](https://img.shields.io/pypi/status/KekikTaban)
![PyPI](https://img.shields.io/pypi/v/KekikTaban)
![PyPI - Downloads](https://img.shields.io/pypi/dm/KekikTaban)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/KekikTaban)
![PyPI - License](https://img.shields.io/pypi/l/KekikTaban)

**[@KekikAkademi](https://github.com/KekikAkademi)** *adına yazılmış Projelerin Terminal Tabanı ve Biraz Dahası*

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![ForTheBadge built-with-love](http://ForTheBadge.com/images/badges/built-with-love.svg)](https://GitHub.com/keyiflerolsun/)

## 🚀 Kurulum

```bash
# Yüklemek
pip install KekikTaban

# Güncellemek
pip install -U KekikTaban
```

## <img src="https://i.imgur.com/ETZ1ABF.png" height="24" align="center"> Kullanım

> ### **[KekikTaban](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/konsolTaban.py)**
```python
from KekikTaban import KekikTaban

taban = KekikTaban(
    baslik   = "@KekikAkademi Userbot",
    aciklama = "kekikUserbot Başlatıldı..",
    banner   = "kekikUserbot",
    girinti  = 1
)

taban.log_salla('a', 'b', 'c')
taban.log_salla('sol', 'orta', 'sag')
taban.log_salla('@keyiflerolsun', '.nekover py', 'Kekik | Kahve')


test = "abcdefghijklmnopqrstuvwxyz"

konsol = taban.konsol
konsol.print(f"{len(test)}", justify="center", style="blink bold red underline on white")

from rich.style import Style
tehlike = Style(color="red", blink=True, bold=True)
konsol.print(f"{len(test)}", justify="center", style=tehlike)

taban.log_salla(test, test, test)

try:
    bakalim()
except Exception as hata:
    taban.hata_salla(hata)
```

### **[slugify](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/ascii_decode.py)**
```python
from KekikTaban import slugify

print(slugify("Ömer Faruk Sancak"))

# » omer-faruk-sancak
```

### **[link_ayikla](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/link_islemleri.py)**
```python
from KekikTaban import link_ayikla

print(link_ayikla("Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent ornare nec turpis at mollis. Aenean iaculis metus libero, a rhoncus justo suscipit quis. Suspendisse sodales ante eros. Curabitur sagittis massa lacus, vel placerat turpis aliquet ac. Nulla porta cursus consequat. Etiam tristique vestibulum maximus. Vestibulum scelerisque vehicula ex, non feugiat eros placerat a. Cras eleifend cursus felis. Nullam pulvinar dictum purus, eu lobortis sapien posuere accumsan. Integer suscipit nisi diam, nec gravida eros malesuada a. Sed vestibulum sollicitudin ex ut volutpat. Phasellus non magna sed neque blandit vestibulum vitae nec ante. https://google.com Proin fringilla ligula nec metus sagittis venenatis."))

# ['https://google.com']
```

### **[youtube_link_mi](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/link_islemleri.py)**
```python
from KekikTaban import youtube_link_mi

print(youtube_link_mi("https://google.com"))

# False
```

### **[okunabilir_byte](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/okunabilir_byte.py)**
```python
from KekikTaban import okunabilir_byte

print(okunabilir_byte(132456498564))

# 123.36 GB
```

### **[zaman_donustur](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/zaman_donustur.py)**
```python
from KekikTaban import zaman_donustur

print(zaman_donustur(123456))

# 1 gün, 10 saat, 17 dakika, 36 saniye
```

### **[qr_ver](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/qr_ver.py)**
```python
from KekikTaban import qr_ver

print(qr_ver("keyiflerolsun"))

                         
#   █▀▀▀▀▀█ ▀▀▀▄▀ █▀▀▀▀▀█  
#   █ ███ █ ▀█ ██ █ ███ █  
#   █ ▀▀▀ █ ▄▄▄██ █ ▀▀▀ █  
#   ▀▀▀▀▀▀▀ ▀▄▀ █ ▀▀▀▀▀▀▀  
#   ▀▄█ ▄ ▀█▄▀▄    █▄▄▀ █  
#   ▀▀▄▄██▀█ ▄▄▀██ ▄▀▄▀▄█  
#     ▀  ▀▀▀███ ▄█▄ █ ▄▀▄  
#   █▀▀▀▀▀█ ▀ ▀▄▀▄  ▀▄▀▄▀  
#   █ ███ █  ▄█▄██▄ ▄▀▄    
#   █ ▀▀▀ █ ▀█▀▄██▀ █▄▀▀▀  
#   ▀▀▀▀▀▀▀ ▀ ▀▀▀   ▀▀  ▀  
```

### **[dict2json](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/dict2json.py)**
### **[dosya_indir](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/dosya_indir.py)**
### **[benim_hwid](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/hwid_kontrol.py)**
### **[hwid_kontrol](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/hwid_kontrol.py)**
### **[satir_ekle](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/txt_fetis.py)**
### **[satirlar_ekle](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/txt_fetis.py)**
### **[list2html](https://github.com/keyiflerolsun/KekikTaban/blob/main/KekikTaban/list2html.py)**

## 💸 Bağış Yap

**[☕️ Kahve Ismarla](https://KekikAkademi.org/Kahve)**

## 🌐 Telif Hakkı ve Lisans

* *Copyright (C) 2022 by* [keyiflerolsun](https://github.com/keyiflerolsun) ❤️️
* [GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007](https://github.com/keyiflerolsun/keyifUserBot/blob/master/LICENSE) *Koşullarına göre lisanslanmıştır..*

## ♻️ İletişim

*Benimle iletişime geçmek isterseniz, **Telegram**'dan mesaj göndermekten çekinmeyin;* [@keyiflerolsun](https://t.me/keyiflerolsun)

##

> **[@KekikAkademi](https://t.me/KekikAkademi)** *için yazılmıştır..*
